#
# spec file for package postfixadmin
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           postfixadmin
Version:        2.3.6
Release:        30.1
License:        GPL-2.0+
Url:            http://postfixadmin.sourceforge.net/
Group:          Productivity/Networking/Web/Frontends
Source0:        %{name}-%{version}.tar.bz2
BuildArch:      noarch

# Web interface
#Requires: httpd, postfix, php, mysql-server
%if %{defined fedora_version} || %{defined centos_version} || %{defined redhat_version} || %{defined rhel_version} || %{defined sl_version}
Requires:	/usr/sbin/sendmail
Requires:	mod_php
Requires:	php_database
Requires:	php-mysql
Requires:	php-spl
%else
Requires:       /usr/sbin/sendmail
Requires:       mod_php_any
Requires:       php_any_db
Recommends:     php-mysql
Requires:       php-spl
%endif

# test/*, xmlrpc.php, squirrelmail plugin
# big dependency, not needed by all users - therefore no hard Requirement
%if %{defined suse_version}
Recommends:     php5-ZendFramework
%endif

# vacation.pl
Requires:       perl(DBI)
Requires:       perl(Email::Valid)
Requires:       perl(MIME::Base64)
Requires:       perl(MIME::EncWords)
Requires:       perl(Mail::Sender)
Requires:       perl(strict)
Requires:       perl(Getopt::Std)
Requires:       perl(Log::Log4perl)
# create vacation user/group
%if %{defined fedora_version} || %{defined centos_version} || %{defined redhat_version} || %{defined rhel_version} || %{defined sl_version}
PreReq:		shadow-utils
%else
PreReq:         pwdutils
%endif

# cleanupdirs.pl
Requires:       perl(File::Path)
Requires:       perl(Getopt::Long)
# mkeveryone.pl
Requires:       perl(Fcntl)
Requires:       perl(IO)
Requires:       perl(IO::File)
Requires:       perl(Time::Local)
Requires:       perl(POSIX)
# fetchmail.pl
Requires:       perl(File::Temp)
Requires:       perl(LockFile::Simple)
Requires:       perl(Sys::Syslog)

%if %{defined fedora_version} || %{defined centos_version} || %{defined redhat_version} || %{defined rhel_version} || %{defined sl_version}
BuildRequires:  httpd-devel
%define serverroot %(/usr/sbin/apxs -q datadir 2>/dev/null || /usr/sbin/apxs -q PREFIX)/html/
%else
BuildRequires:  apache2-devel
%define serverroot %(/usr/sbin/apxs2 -q datadir 2>/dev/null || /usr/sbin/apxs2 -q PREFIX)/htdocs/
Recommends:     postfix
Suggests:       php-pgsql
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Summary:        Web-based management tool for Postfix virtual domains, mailboxes and aliases

%description
PostfixAdmin is a PHP based application that handles Postfix Style Virtual Domains and
Users that are stored in MySQL or PostgreSQL.

Postfix Admin supports:
- Virtual Mailboxes / Virtual Aliases / Forwarders
- Alias domains (Domain to Domain forwarding with recipient validation)
- Vacation (auto-response) for Virtual Mailboxes.
- Quota / Alias & Mailbox limits per domain.
- Fetchmail integration
- Packaged with over 25 languages.

%prep
%setup -q

%build
echo "*** serverroot: %{serverroot} ***"

%install
mkdir -p -m0755 %{buildroot}%{_sysconfdir}/%{name}
#mkdir -p -m0755 %{buildroot}%{_datadir}/%{name}
mkdir -p -m0755 %{buildroot}%{serverroot}/%{name}
mkdir -p -m0755 %{buildroot}%{_localstatedir}/spool/vacation
mkdir -p -m0755 %{buildroot}/%{_prefix}/lib/%{name}

# install the config files
#install -m 0640 config.inc.php.sample %{buildroot}%{_sysconfdir}/%{name}/config.inc.php
#ln -s ../../../..%{_sysconfdir}/%{name}/config.inc.php \
#    %{buildroot}%{_datadir}/%{name}/config.inc.php

install -m 0644 *.php motd*.txt %{buildroot}%{serverroot}/%{name}/

mv VIRTUAL_VACATION/vacation.pl %{buildroot}%{_prefix}/lib/%{name}/
# compatibility symlink to match documentation
( cd %{buildroot}%{_localstatedir}/spool/vacation/ && ln -s ../../../usr/lib/%{name}/vacation.pl )

# copy over the rest
for d in admin images languages model templates users css; do
    cp -rp $d %{buildroot}%{serverroot}/%{name}/
done

# remove files related to debian packaging (to avoid it's copied as %doc)
rm -r ADDITIONS/squirrelmail-plugin/debian/
rm -r ADDITIONS/cyrus/
cp -rp ADDITIONS %{buildroot}%{_prefix}/lib//%{name}/
chmod 755 %{buildroot}%{_prefix}/lib/%{name}/ADDITIONS/*.{pl,sh,py}

# install the config file
#mkdir -p %{buildroot}%{_sysconfdir}/apache2/conf.d
#install -m 644 $RPM_SOURCE_DIR/%{name}.conf \
#   %{buildroot}%{_sysconfdir}/apache2/conf.d/

%pre
getent group  vacation >/dev/null || groupadd vacation || :
getent passwd vacation >/dev/null || useradd -c "Virtual Vacation" -d %{_localstatedir}/spool/vacation -s /sbin/nologin -M -r vacation || :
#if [ -z "`grep vacation /etc/postfix/master.cf 2>/dev/null`" ]; then
#cat <<'EOF' >>/etc/postfix/master.cf
## Postfix Admin Vacation
#vacation	unix	-	n	n	-	-	pipe
#	flags=Rq user=vacation argv=/usr/lib/postfixadmin/vacation.pl -f ${sender} -- ${recipient}
#EOF
#fi

#%preun
#if [ $1 = 0 ]; then
#    /usr/sbin/userdel vacation 2>/dev/null || :
#fi

%files
%defattr(-,root,root)
#%config %dir %{_sysconfdir}/%{name}
#%attr(640,root,www) %config(noreplace) %{_sysconfdir}/%{name}/*.php
#%config(noreplace) %{_sysconfdir}/apache2/conf.d/*.conf
%doc DOCUMENTS/* *.TXT VIRTUAL_VACATION
%{serverroot}/%{name}/
%dir %{_prefix}/lib/%{name}/
%{_prefix}/lib/%{name}/ADDITIONS/
%attr( 750,root,vacation)       %{_prefix}/lib/%{name}/vacation.pl
%attr(1770,root,vacation) %dir %{_localstatedir}/spool/vacation
%{_localstatedir}/spool/vacation/vacation.pl

%changelog
* Thu Feb 14 2013 cs@linux-administrator.com
- Update to release 2.3.6
